==> share_apps-0.0.14.tar.gz: lib/widgets/widgets_importer.dart <==
import 'dart:ui';

import 'package:flutter/material.dart';
import 'package:share_apps/utils/common_utils.dart';
import 'package:share_apps/utils/string_utils.dart';

Widget AddText(String text, Color color, double size, FontWeight weight,
    bool isUnderLine) {
  return Text(text,
      textAlign: TextAlign.center,
      style: TextStyle(
          color: color,
          fontSize: size,
          fontWeight: weight,
          decoration:
              isUnderLine ? TextDecoration.underline : TextDecoration.none));
}

Widget AddSizeBox(double _height, double _width) {
  return SizedBox(
    height: _height,
    width: _width,
  );
}

Widget AddTextField(
    BuildContext context,
    TextInputType inputType,
    TextInputAction textInputAction,
    String hint,
    FocusNode _focus,
    FocusNode _next_focus,
    TextEditingController editingController) {
  return TextFormField(
    controller: editingController,
    validator: (value) {
      if (value.isEmpty) {
        return 'Enter ' + hint;
      } else if (inputType == TextInputType.emailAddress) {
        return CommonUtils.validateEmail(value)
            ? null
            : StringUtils.CHECK_EMAIL_VALIDATION;
      }
      return null;
    },
    keyboardType: inputType,
    focusNode: _focus,
    onFieldSubmitted: (term) {
      _focus.unfocus();
      FocusScope.of(context).requestFocus(_next_focus);
    },
    textInputAction: textInputAction,
    decoration: InputDecoration(
      contentPadding: EdgeInsets.all(15.0),
      border: OutlineInputBorder(),
      hintText: hint,
    ),
  );
}

Widget addProgress() {
  return Opacity(
    opacity: 0.6,
    child: Container(
        color: Colors.black,
        height: double.maxFinite,
        width: double.maxFinite,
        child: Center(
            child: CircularProgressIndicator(
          backgroundColor: Colors.black,
        ))),
  );
}

==> share_apps-0.2.13.tar.gz: lib/widgets/widgets_importer.dart <==
import 'package:flutter/material.dart';
import 'package:share_apps/utils/common_utils.dart';
import 'package:share_apps/utils/string_utils.dart';

Widget AddText(String text, Color color, double size, FontWeight weight,
    bool isUnderLine) {
  return Text(text,
      textAlign: TextAlign.center,
      style: TextStyle(
          color: color,
          fontSize: size,
          fontWeight: weight,
          decoration:
              isUnderLine ? TextDecoration.underline : TextDecoration.none));
}

Widget AddSizeBox(double _height, double _width) {
  return SizedBox(
    height: _height,
    width: _width,
  );
}

Widget AddTextField(
    BuildContext context,
    TextInputType inputType,
    TextInputAction textInputAction,
    String hint,
    FocusNode _focus,
    FocusNode _next_focus,
    TextEditingController editingController) {
  return TextFormField(
    controller: editingController,
    validator: (value) {
      if (value == null || value.isEmpty) {
        return 'Enter $hint';
      } else if (inputType == TextInputType.emailAddress) {
        return CommonUtils.validateEmail(value)
            ? null
            : StringUtils.CHECK_EMAIL_VALIDATION;
      }
      return null;
    },
    keyboardType: inputType,
    focusNode: _focus,
    onFieldSubmitted: (term) {
      _focus.unfocus();
      FocusScope.of(context).requestFocus(_next_focus);
    },
    textInputAction: textInputAction,
    decoration: InputDecoration(
      contentPadding: const EdgeInsets.all(15.0),
      border: const OutlineInputBorder(),
      hintText: hint,
    ),
  );
}

Widget addProgress() {
  return Opacity(
    opacity: 0.6,
    child: Container(
        color: Colors.black,
        height: double.maxFinite,
        width: double.maxFinite,
        child: const Center(
            child: CircularProgressIndicator(
          backgroundColor: Colors.black,
        ))),
  );
}
